import request from '@/utils/request'

// 模版列表
export function selectMessageShow(data) {
  return request({
    url: '/car/template/selectTemplateShow',
    method: 'post',
    data
  })
}

// 查找模版,回显
export function selectTemplateByTemplateId(templateId) {
  return request({
    url: '/car/template/selectTemplateByTemplateId?templateId='+templateId,
    method: 'post'
  })
}

// 添加模版
export function insertTemplate(data) {
  return request({
    url: '/car/template/insertTemplate',
    method: 'post',
    data
  })
}

// 模版修改
export function updataTemplate(data) {
  return request({
    url: '/car/template/updataTemplate',
    method: 'post',
    data
  })
}

// 模版删除
export function deleteTemplate(templateIds) {
  return request({
    url: '/car/template/deleteTemplate?ids='+templateIds,
    method: 'post'
  })
}



